@@ -6,9 +6,9 @@ from deckz.running import run_all as running_run_all
 
 @app.command()
 def run_all(
-    handout: bool = False,
+    handout: bool = True,
     presentation: bool = True,
-    print: bool = False,
+    print: bool = True,
     directory: Path = Path("."),
 ) -> None:
     """Compile all shared slides."""
